import { useEffect, useRef } from "react";
import { Flex, Tabs } from "antd";
import styles from "./index.less";
import "./index.less"
import { Graph, Shape } from "@antv/x6";
import { Scroller } from '@antv/x6-plugin-scroller'
import Libary from '../Libary';
import { useModel } from "umi";
export default function Content() {
  const { initGraph } = useModel('graphModel');
  
  useEffect(() => {
    const graph = new Graph({
      container: document.getElementById("graph-container")!,
      autoResize: true,
      width: 2000,
      height: 2000,
      mousewheel: {
        enabled: true,
        zoomAtMousePosition: true,
        modifiers: 'ctrl',
        minScale: 0.2,
        maxScale: 2,
      },
      // 查找父节点
      embedding: {
        enabled: true,
        findParent({ node }) {
          const bbox = node.getBBox()
          return this.getNodes().filter((node) => {
            const data = node.getData<{ isPage: boolean }>()
            if (data && data.isPage) {
              const targetBBox = node.getBBox()
              return bbox.isIntersectWithRect(targetBBox)
            }
            return false
          })
        },
      },
      background: {
        color: '#eaecee',
      },
      interacting: {
        edgeLabelMovable: true,
        edgeMovable: true,
        nodeMovable: (view) => {
          const data = view.cell.getData<{ isPage: boolean }>()
          return !data || !data.isPage
        },
      },
      connecting: {
        router: 'manhattan',
        connector: {
          name: 'rounded',
          args: {
            radius: 8,
          },
        },
        anchor: 'center',
        connectionPoint: 'anchor',
        allowBlank: true,
        snap: {
          radius: 20,
        },
        createEdge() {
          return new Shape.Edge({
            attrs: {
              line: {
                stroke: '#A2B1C3',
                strokeWidth: 2,
                targetMarker: {
                  name: 'block',
                  width: 12,
                  height: 8,
                },
              },
            },
            tools: ['segments', 'vertices'],
            zIndex: 0,
          })
        },
        validateConnection({ targetMagnet }) {
          return !!targetMagnet
        },
      },
      highlighting: {
        magnetAdsorbed: {
          name: 'stroke',
          args: {
            attrs: {
              fill: '#f00',
              stroke: '#5F95FF',
            },
          },
        },
      },
    });

    graph.use(new Scroller({
      enabled: true
    }));
    initGraph(graph);
  }, []);

  return (
    <Flex className="h-full">
      <div className={styles.leftPanel}>
        <Tabs className="h-full" centered items={[
          {
            key: '1',
            label: '组件库',
            children: <Libary />
          },
          {
            key: '2',
            label: '风格',
            children: <div>风格面板</div>
          }
        ]}/>
      </div>
      <div className={styles.designLayout} style={{width: '100%', height: '100%'}}>
        <div id="graph-container"></div>
      </div>
    </Flex>
  );
}
